##
##  hugo.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_hugo_base  0.147.2
%define       V_hugo_snap  20250507

#   package information
Name:         hugo
Summary:      Static Website Generator
URL:          http://gohugo.io/
Vendor:       Steve Francia
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      Apache
Version:      %{V_hugo_base}.%{V_hugo_snap}
Release:      20250507

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/hugo/hugo-%{V_hugo_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Hugo is a static HTML and CSS website generator written in Go. It
    is optimized for speed, easy use and configurability. Hugo takes a
    directory with content and templates and renders them into a full
    HTML website. Hugo relies on Markdown files with front matter for
    meta data. And you can run Hugo from any directory. This works
    well for shared hosts and other systems where you don’t have a
    privileged account. Hugo renders a typical website of moderate size
    in a fraction of a second. A good rule of thumb is that each piece
    of content renders in around 1 millisecond. Hugo is designed to work
    well for any kind of website including blogs, tumbles and docs.

%track
    prog hugo = {
        version   = %{V_hugo_base}
        url       = https://github.com/gohugoio/hugo/releases
        regex     = v(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n hugo

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/gohugoio/hugo
    go build -v \
        -ldflags "-X github.com/gohugoio/hugo/hugolib.CommitHash=000000 -X github.com/gohugoio/hugo/hugolib.BuildDate=`date +%FT%T%z`" \
        -o hugo main.go

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/gohugoio/hugo/hugo \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

